@@ -1,5 +1,5 @@
 from abc import ABC
-from src.shared.event_system import SharedEventSystem
+from ..shared.event_system import SharedEventSystem
 
 
 class EventListener(ABC):
